@@ -123,7 +123,7 @@ class CrowdTangle:
         response = self.make_request_leader(payload)
         return response.json()
 
-    def get_post(self, include_history='none', post_id=''):
+    def get_post(self, include_history=None, post_id=''):
         """
         Returns the post with the id passed
         Args:
@@ -135,11 +135,12 @@ class CrowdTangle:
         """
         payload = {'includeHistory': include_history}
         response = self.make_request_post(payload=payload, post_id=post_id)
+        print(respose)
         return response.json()
 
     def get_posts(self, accounts=None, branded_content=None, count=None, end_date=None, include_history=None,
-                 language=None, list_ids=None, min_interactions=None, offset=None, page_admin_top_country=None,
-                 search_term=None, sort_by=None, start_date=None, timeframe=None, types=None, verified=None):
+                  language=None, list_ids=None, min_interactions=None, offset=None, page_admin_top_country=None,
+                  search_term=None, sort_by=None, start_date=None, timeframe=None, types=None, verified=None):
         """
 
         Args:
